@@ -45,6 +45,10 @@ class FacebookScraper:
         self.requests_kwargs = requests_kwargs
 
     def get_posts(self, account: str, **kwargs) -> Iterator[Post]:
+        if 'cookie_locale' in kwargs:
+            print("cookie_locale:%s" % kwargs['cookie_locale'])
+            self.default_headers['cookie'] = 'locale=%s;' % kwargs['cookie_locale']
+            self.session.headers.update(self.default_headers)
         iter_pages_fn = partial(iter_pages, account=account, request_fn=self.get)
         return self._generic_get_posts(extract_post, iter_pages_fn, **kwargs)
 
